@@ -1,7 +1,7 @@
 use std::convert::TryInto;
 
 use clap::ArgMatches;
-use miette::{IntoDiagnostic, Result};
+use miette::Result;
 use mit_commit_message_lints::{external, lints::read_from_toml_or_else_vcs};
 use mit_lint::Lints;
 
@@ -37,9 +37,5 @@ fn get_selected_lints(args: &ArgMatches) -> Result<Lints> {
         return Err(LintNameNotGiven.into());
     }
 
-    lint_names
-        .unwrap()
-        .collect::<Vec<_>>()
-        .try_into()
-        .into_diagnostic()
+    Ok(lint_names.unwrap().collect::<Vec<_>>().try_into()?)
 }
